

OrMaxLIMIT <- 1.0

ProbORtoRR <- function(Env, OR) {
  incid = Env * OR
  if( incid >= 1.0 ) {
    incid = 1.0
  }
  result <- (OR / ( 1.0 + incid*(OR-1.0)))

  return( result * Env)
}


LifeTimeRisk <- function(nAgesEntries, OR, mortOffset, stillAlive, atable, mortalityChoice ) {
  
  ltRisk = 0.0
  t = 1
  while(t <= nAgesEntries) {
    
    density = 0
    
    if( t > 1 && ltRisk < OrMaxLIMIT  ) {
      mortalityMultiplier = 1
      mortAge = mortOffset + t;
      if(mortAge > 0 ) {
        if( mortalityChoice == 'm' ) {
          mortalityMultiplier = stillAlive$men[mortAge]
        } else if( mortalityChoice == 'w' ) {
          mortalityMultiplier = stillAlive$women[mortAge]
        } else {
          mortalityMultiplier = (stillAlive$women[mortAge] + stillAlive$men[mortAge])/2; # default
        }
      }
      
      prob = ProbORtoRR(atable$Env[t], OR);
      if( prob > 1.0) {
        prob = 1.0
      }
      density = (prob * mortalityMultiplier )
      
      if( t > 1 ) {  #incidence is 0 in first decades of life in any case
        ltRisk = ltRisk + density
      }
      
    }
    
    t = t + 1
  }  

  if( ltRisk > 1.0 )  {
    ltRisk = 1.0
  }
  
  return( ltRisk)
}




LifeTimeRiskAge <- function(nAgesEntries, OR, mortOffset, stillAlive, atable, mortalityChoice ) {
  
  ageLimit = 0
  ltRisk = 0.0
  t = 1
  while(t <= nAgesEntries) {
    
    density = 0
    
    if( t > 1 && ltRisk < OrMaxLIMIT  ) {
      mortalityMultiplier = 1
      mortAge = mortOffset + t;
      if(mortAge > 0 ) {
        if( mortalityChoice == 'm' ) {
          mortalityMultiplier = stillAlive$men[mortAge]
        } else if( mortalityChoice == 'w' ) {
          mortalityMultiplier = stillAlive$women[mortAge]
        } else {
          mortalityMultiplier = (stillAlive$women[mortAge] + stillAlive$men[mortAge])/2; # default
        }
      }
      
      prob = ProbORtoRR(atable$Env[t], OR);
      if( prob > 1.0) {
        prob = 1.0
      }
      density = (prob * mortalityMultiplier )
      
      if( t > 1 ) {  #incidence is 0 in first decades of life in any case
        ltRisk = ltRisk + density
      }
      ageLimit = t     
       
    }
    
    t = t + 1
  }  
  
  return( ageLimit)
}





SaveDataFrameToFile <- function(DataFr, fileName) {
  # save all incidence, original and with 5, 10,   
  write.table(format( DataFr, digits=8, scientific=TRUE, trim = TRUE),
              file = fileName,
              row.names = FALSE,
              col.names = TRUE,
              sep = ",",
              quote = FALSE )
}


SaveDataSetToFile <- function( age, A, filename) {
  IncDataFr = data.frame( age, A[[1]], A[[2]],A[[3]],A[[4]],A[[5]],A[[6]],A[[7]],A[[8]],A[[9]], A[[10]], A[[11]], A[[12]],A[[13]],A[[14]],A[[15]],A[[16]],A[[17]],A[[18]],A[[19]], A[[20]] )
  SaveDataFrameToFile(IncDataFr, filename) 
  rm( IncDataFr);
}




main <- function() {
  args <- commandArgs(trailingOnly = TRUE)
  
  pathname <- args[1]  # path to the result file
  
#  pathname <- "d:/Science1_data/Frailty/yearlyORtoRR/LODsCommonLow"

  diseaseFolders <- c( "Alzheimers","T2D","Stroke", "CAD", "BreastCancer","ProstateCancer",	"ColorectalCancer","LungCancer") #,"HipOsteoarthritis");
  mortalityList <- c( "b","b","b","b","w","m","b","b")

  ageBrackets <- c(0,5,10,15);
  orArray <- c(16,4,1,0.25,0.0625);
  mortalityOffsetArray <- c(0,-5,-10,-15);
  
  
  disease <- 1
  Ndiseases <- length(diseaseFolders)

  stillAlive = read.csv("./StillAliveTable.csv")
  
  ORinitial = 4.0  # Change this value to enter OR compared to OR = 1.0
  ORtoCompare = 1.0  # Change this value to enter OR compared to OR = 1.0
  
  while ( disease <= Ndiseases) {
    mortalityChoice <- mortalityList[disease]
    filename <- paste( pathname, "/", diseaseFolders[disease], "/EnvironmentArray.csv", sep="");
    atable <- read.table(filename, header=TRUE, sep=",", quote="" )
    
    nAgesEntries = length(atable$Age)
 
    age <- c(1:nAgesEntries)
  
    lr0 = 0.0
    lrC = 0.0
    delayYears = 0
    ageInitial = 0

    print( " - - - - -")
    
    assign("OrMaxLIMIT", 1.0, envir = .GlobalEnv)
#    print( OrMaxLIMIT)
    max_value = LifeTimeRisk( nAgesEntries, ORinitial, 0, stillAlive, atable, mortalityChoice ) 
#    print( max_value)

    max_value = max_value * 0.3
    assign("OrMaxLIMIT", max_value, envir = .GlobalEnv)
    assign("OrMaxLIMIT", 0.99, envir = .GlobalEnv)
    
#    print( OrMaxLIMIT)
    
    lr0 = LifeTimeRisk( nAgesEntries, ORinitial, 0, stillAlive, atable, mortalityChoice )
    if( lr0>OrMaxLIMIT) {
      ageInitial = LifeTimeRiskAge( nAgesEntries, ORinitial, 0, stillAlive, atable, mortalityChoice )
    }
    lrOR = LifeTimeRisk( nAgesEntries, ORtoCompare, delayYears, stillAlive, atable, mortalityChoice )
    
    repeat {
      lrC = LifeTimeRisk( nAgesEntries, ORtoCompare, -delayYears, stillAlive, atable, mortalityChoice )

      if(lr0<lrC || delayYears==200) {
        if( lr0>OrMaxLIMIT) {
          delayYears = LifeTimeRiskAge( nAgesEntries, ORtoCompare, -delayYears+1, stillAlive, atable, mortalityChoice )  - ageInitial
        }
        break;
      }
      
      delayYears = delayYears + 1
    }
  
    print(diseaseFolders[disease])
    print(delayYears)
    print(lr0)
    print(lrOR)    

    disease <- disease + 1
  }  
}

# CALL MY MAIN() 
main()



  