

ProbORtoRR <- function(Env, OR) {
  incid = Env * OR
  if( incid >= 1.0 ) {
    incid = 1.0
  }
  result <- (OR / ( 1.0 + incid*(OR-1.0)))

  return( result * Env)
}


SaveDataFrameToFile <- function(DataFr, fileName) {
  # save all incidence, original and with 5, 10,   
  write.table(format( DataFr, digits=8, scientific=TRUE, trim = TRUE),
              file = fileName,
              row.names = FALSE,
              col.names = TRUE,
              sep = ",",
              quote = FALSE )
}


SaveDataSetToFile <- function( age, A, filename) {
  IncDataFr = data.frame( age, A[[1]], A[[2]],A[[3]],A[[4]],A[[5]],A[[6]],A[[7]],A[[8]],A[[9]], A[[10]], A[[11]], A[[12]],A[[13]],A[[14]],A[[15]],A[[16]],A[[17]],A[[18]],A[[19]], A[[20]] )
  SaveDataFrameToFile(IncDataFr, filename) 
  rm( IncDataFr);
}




main <- function() {
  args <- commandArgs(trailingOnly = TRUE)
  
  pathname <- args[1]  # path to the result file
  
#  pathname <- "d:/Science1_data/Frailty/yearlyORtoRR/LODsCommonLow"

  diseaseFolders <- c( "Alzheimers","T2D","Stroke", "CAD", "BreastCancer","ProstateCancer",	"ColorectalCancer","LungCancer") #,"HipOsteoarthritis");
  mortalityList <- c( "b","b","b","b","w","m","b","b")

  ageBrackets <- c(0,5,10,15);
  orArray <- c(16,4,1,0.25,0.0625);
  mortalityOffsetArray <- c(0,-5,-10,-15);
  
  
  disease <- 1
  Ndiseases <- length(diseaseFolders)

  stillAlive = read.csv("./StillAliveTable.csv")
  
  mortalityOffsetCount = length(mortalityOffsetArray)
  orCount = length(orArray)
  nArraysCount = mortalityOffsetCount * orCount
  
  # load summary prevalences for all diseases for further analysis
  while ( disease <= Ndiseases) {
    mortalityChoice <- mortalityList[disease]
    filename <- paste( pathname, "/", diseaseFolders[disease], "/EnvironmentArray.csv", sep="");
    atable <- read.table(filename, header=TRUE, sep=",", quote="" )
    
    nAgesEntries = length(atable$Age)
 
    age <- c(1:nAgesEntries)
    
    #make an initialized to 0 array # of incidence densities
    incid <- rep(0, nAgesEntries)
    
    densityArray <- list(incid, incid) # form a list of vectors
    for( i in 1:nArraysCount) { #now allocate as many vector entries as will be needed. They will go OR16_00, OR16_05..., 0Ri16_00, etc - four age extensions for each OR value
      densityArray[[i]] <- incid
    }
    
    lifetimeRiskArray <- densityArray # will need the same dimensions lifetime risk array
    bReachedLimit = 0;
    
    t = 1
    while(t <= nAgesEntries) {
      
      density = 0
      
      for( or in 1:orCount) {
        for( mortOffset in 1:mortalityOffsetCount) {
          nVectorAccessed = mortalityOffsetCount*(or - 1) + mortOffset;
          
          if( t > 1 && lifetimeRiskArray[[nVectorAccessed]][t-1] >= 1.0  ) {
            densityArray[[nVectorAccessed]][t] = 0;
            lifetimeRiskArray[[nVectorAccessed]][t] = 1.0;            
          } else {
            mortalityMultiplier = 1
            mortAge = mortalityOffsetArray[mortOffset] + t;
            if(mortAge > 0 ) {
              if( mortalityChoice == 'm' ) {
                mortalityMultiplier = stillAlive$men[mortAge]
              } else if( mortalityChoice == 'w' ) {
                mortalityMultiplier = stillAlive$women[mortAge]
              } else {
                mortalityMultiplier = (stillAlive$women[mortAge] + stillAlive$men[mortAge])/2; # default
              }
            }
            
            prob = ProbORtoRR(atable$Env[t], orArray[or]);
            if( prob > 1.0) {
              prob = 1.0
            }
            density = (prob * mortalityMultiplier )
            densityArray[[nVectorAccessed]][t] = density
            
            if( t > 1 ) {  #incidence is 0 in first decades of life in any case
              lifetimeRiskArray[[nVectorAccessed]][t] = lifetimeRiskArray[[nVectorAccessed]][t-1] + density
              if( lifetimeRiskArray[[nVectorAccessed]][t] > 1.0 ) {
                densityArray[[nVectorAccessed]][t] = density - lifetimeRiskArray[[nVectorAccessed]][t] + 1.0;
                lifetimeRiskArray[[nVectorAccessed]][t] = 1.0;
              }
            }
          }
        }
      }
      
      t = t + 1
    }
    
    filename <- paste( pathname, "/", diseaseFolders[disease], "/DensityPostAnalysis.csv", sep="");
    SaveDataSetToFile( age, densityArray, filename)
    
    filename <- paste( pathname, "/", diseaseFolders[disease], "/LifetimeRiskPostAnalysis.csv", sep="");
    SaveDataSetToFile( age, lifetimeRiskArray, filename)
    
    disease <- disease + 1
  }  
}

# CALL MY MAIN() 
main()



  